@@ -43,8 +43,8 @@ class EngineExplorer : public QDialog, public Ui::EngineExplorer
     Q_OBJECT
 
     public:
-        explicit EngineExplorer(QWidget *parent = 0);
-        ~EngineExplorer();
+        explicit EngineExplorer(QWidget *parent = nullptr);
+        ~EngineExplorer() override;
 
         void setApp(const QString &app);
         void setEngine(const QString &engine);
